---
id: 20211123221647
title: Collect links by tag
tags: [zettel, markdown, tag]
---

# Collect links by tag

MkDocs Zettelkasten plugin creates the page containing the list of all tags found in markdown documents with the links to those documents.

Every tag in the list of tags printed in [card's header](20211123213357) can be clicked to navigate to the tags page. You can find other zettels with the same tag this way.
